@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -23,10 +23,8 @@
 #include "messagingwidget.h"
 #include "../../im/improtocols.h"
 #include "../../widgets/contacteditorcombobox.h"
-#include <QComboBox>
 #include <KLocalizedString>
 #include <QHBoxLayout>
-#include <KLineEdit>
 #include <QToolButton>
 #include <editor/widgets/preferredlineeditwidget.h>
 
@@ -68,7 +66,7 @@ MessagingWidget::MessagingWidget(QWidget *parent)
     mRemoveButton = new QToolButton(this);
     mRemoveButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
     mRemoveButton->setObjectName(QStringLiteral("removebutton"));
-    mRemoveButton->setToolTip(i18n("Add IM"));
+    mRemoveButton->setToolTip(i18n("Remove IM"));
     connect(mRemoveButton, &QToolButton::clicked, this, &MessagingWidget::slotRemoveMessaging);
     layout->addWidget(mRemoveButton);
 }
@@ -120,3 +118,11 @@ void MessagingWidget::clearWidget()
     mProtocolCombo->setCurrentIndex(0);
     mMessagingEdit->clear();
 }
+
+void MessagingWidget::setReadOnly(bool readOnly)
+{
+    mMessagingEdit->setReadOnly(readOnly);
+    mAddButton->setEnabled(!readOnly);
+    mRemoveButton->setEnabled(!readOnly);
+    mProtocolCombo->setEnabled(!readOnly);
+}
